@@ -14,6 +14,7 @@
 
 #ifndef _Included_org_gnu_gtk_CellView
 #define _Included_org_gnu_gtk_CellView
+#include "org_gnu_gtk_CellView.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -115,21 +116,18 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_CellView_gtk_1cell_1view_1get_1displa
  * Class:     org_gnu_gtk_CellView
  * Method:    gtk_cell_view_get_size_of_row
  */
-JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_CellView_gtk_1cell_1view_1get_1size_1of_1row
-  (JNIEnv *env, jclass cls, jobject view, jobject path, jobject req)
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_CellView_gtk_1cell_1view_1get_1size_1of_1row
+  (JNIEnv *env, jclass cls, jobject view, jobject path)
 {
-	GtkCellView* view_g = (GtkCellView*)getPointerFromHandle(env, view);
-	GtkTreePath* path_g = (GtkTreePath*)getPointerFromHandle(env, path);
-	GtkRequisition* req_g = (GtkRequisition*)getPointerFromHandle(env, req);
-	jboolean ret;
-	if (!req_g) {
-		req_g = g_new(GtkRequisition, 1);
-		ret = (jboolean)gtk_cell_view_get_size_of_row(view_g, path_g, req_g);
-		updateHandle(env, req, req_g);
-	} else {
-		ret = (jboolean)gtk_cell_view_get_size_of_row(view_g, path_g, req_g);
-	}
-	return ret;
+	GtkCellView* view_g;
+	GtkTreePath* path_g;
+	GtkRequisition* req;
+	path_g = (GtkTreePath*)getPointerFromHandle(env, path);
+	view_g = (GtkCellView*)getPointerFromHandle(env, view);
+	req = g_new(GtkRequisition, 1);
+	gtk_cell_view_get_size_of_row(view_g, path_g, req);
+	return getGBoxedHandle(env, req, GTK_TYPE_REQUISITION, NULL,
+			(GBoxedFreeFunc) gtk_requisition_free);
 }
 
 /*
